@@ -83,6 +83,10 @@ void ExportAlarmJobInterfaceTestImpl::convertCollectionIdsToRealPath(KConfigGrou
 QString
 ExportAlarmJobInterfaceTestImpl::createResource(const QString &resources, const QString &name, const QMap<QString, QVariant> &settings, bool synchronizeTree)
 {
+    Q_UNUSED(resources);
+    Q_UNUSED(name);
+    Q_UNUSED(settings);
+    Q_UNUSED(synchronizeTree);
     Q_UNREACHABLE();
     return {};
 }
