@@ -95,6 +95,10 @@ QString ExportCalendarsJobInterfaceTestImpl::createResource(const QString &resou
                                                             const QMap<QString, QVariant> &settings,
                                                             bool synchronizeTree)
 {
+    Q_UNUSED(resources);
+    Q_UNUSED(settings);
+    Q_UNUSED(name);
+    Q_UNUSED(synchronizeTree);
     Q_UNREACHABLE();
     return {};
 }
